.. pyDeltaRCM documentation master file

Welcome to the PyDeltaRCM documentation
#########################################

*pyDeltaRCM* is a computationally efficient, free and open source, and easy-to-customize numerical delta model based on the original DeltaRCM model design (`Matlab DeltaRCM <https://csdms.colorado.edu/wiki/Model:DeltaRCM>`_ model by Man Liang).
*pyDeltaRCM* delivers improved model stability and capabilities, infrastructure to support exploration with minimal boilerplate code, and establishes an approach to extending model capabilities that ensures reproducible and comparable studies.

.. plot:: guides/cover.py

    The weighted random walk of 20 water parcels in a *pyDeltaRCM* model run with default parameters.


Project information
###################

.. image:: https://badge.fury.io/gh/DeltaRCM%2FpyDeltaRCM.svg
    :target: https://github.com/DeltaRCM/pyDeltaRCM/releases

.. image:: https://badge.fury.io/py/pyDeltaRCM.svg
    :target: https://badge.fury.io/py/pyDeltaRCM

.. image:: https://img.shields.io/static/v1?label=GitHub&logo=github&message=source&color=brightgreen
    :target: https://github.com/DeltaRCM/pyDeltaRCM

.. image:: https://joss.theoj.org/papers/10.21105/joss.03398/status.svg
   :target: https://joss.theoj.org/papers/10.21105/joss.03398

.. toctree::
   :maxdepth: 1

   meta/installing
   meta/contributing
   meta/license
   meta/conduct
   meta/citing
   meta/usedby


.. _user_documentation:

User documentation
##################

.. toctree::
   :maxdepth: 2

   guides/getting_started
   guides/user_guide
   info/index
   examples/index
   examples/modelzoo



Developer documentation
#######################

.. image:: https://badge.fury.io/py/pyDeltaRCM.svg
    :target: https://badge.fury.io/py/pyDeltaRCM

.. image:: https://github.com/DeltaRCM/pyDeltaRCM/actions/workflows/build.yml/badge.svg
    :target: https://github.com/DeltaRCM/pyDeltaRCM/actions

.. image:: https://codecov.io/gh/DeltaRCM/pyDeltaRCM/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/DeltaRCM/pyDeltaRCM

.. image:: https://app.codacy.com/project/badge/Grade/1c137d0227914741a9ba09f0b00a49a7
    :target: https://app.codacy.com/gh/DeltaRCM/pyDeltaRCM/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade

.. toctree::
   :maxdepth: 3

   guides/developer_guide
   reference/index
